%========================================================================================================%
%                   Komandna datoteka startC.m pokrece SIMULINK model c.mdl                              %
%========================================================================================================%
clear; clc;
%--------------------------------------------------------------------------------------------------------%
T = 0.0003;                             % [s]; perioda odabiranja regulatora brzine
Wmax = 100*pi;                          % [rad/s]; max Wref
%--------------------------------------------------------------------------------------------------------%
% ELEKTRICNI PODSISTEM
Km = 1;                                 % pojacanje aktuatora
psi = 0.3;                              % faktor relativnog prigusenja elektricnog podsistema
Wn = 4430;                              % [rad/s]; neprigusena prirodna ucestanost
                                        % elektricnog podsistema
Te = 1/(2*psi*Wn);                      % [s]; dominantna vremenska konstanta 
                                        % elektricnog podsistema; [izraz (10b)]
Tmax = 10;                              % [Nm]; maksimalna vrednost pokretackog momenta
%--------------------------------------------------------------------------------------------------------%
% PARAMETRI MEHANICKOG PODSISTEMA SA ELASTICNOM SPOJNICOM
Jm = 0.0008;                            % [kgm2]; inercija elektricne masine
Fm = 0.002;                             % [Nm/rad/s]; frikcija elektricne masine
JL = 0.0002;                            % [kgm2]; inercija opterecenja
FL = 0.002;                             % [Nm/rad/s]; frikcija opterecenja
Ko = 150;                               % [Nm/rad]; krutost osovine
Kv = 0;                                 % [Nm/rad/s]; koeficijent viskoznog trenja osovine
J = Jm + JL;                            % [kgm2]; ukupna inercija
%--------------------------------------------------------------------------------------------------------%
% DAVAC-SINHROKONVERTOR
N = 12;                                 % [broj bita]; rezolucija sinhrokonvertora
Fbw = 1000;                             % [Hz]; propusni opseg sinhrokonvertora
kvant = 2^(16-N);                       % kvantizacioni interval sinhrokonvertora
An = 2/(pi*Fbw);                        % koeficijent normalizacije operatora s-domena u odnosu na 
                                        % granicnu ucestanost Fbw; [izraz (12c)]
Kn = 2^16/(2*pi);                       % prenosni odnos sinhrokonvertora; [izraz (12b)]
Trd = 0.33/Fbw;                         % [s]; dominantna vremenska konstanta sinhrokonvertora; 
                                        % [izraz (13b)]
%--------------------------------------------------------------------------------------------------------%
% DOMINANTNA VREMENSKA KONSTANTA
Tau = sqrt(Te^2 + Trd^2);               % [s]; [izraz (35)]
%--------------------------------------------------------------------------------------------------------%
% REGULATOR BRZINE
Nreg = 24;                              % [broj bita]; tacnost regulatora brzine
% PRORACUN PARAMETARA REGULATORA BRZINE PREMA UPUTSTVU
b = exp(-T/Tau);                        % parametar BETA; [izraz (34)]
C = (Km*Kn*T)/(2*J);                    % sinteticki koeficijent; [izraz (33c)]      
Sopt = (4 + 4*b)^(1/3) - 1;             % optimalni trostruki pol brzinskog servomehanizma; [izraz (45)]
KP = (Sopt^3 - b)/((1 - b)*C);          % koeficijent proporcionalnog dejstva; [izraz (46)]   
KI = (3*Sopt^2 - 1 - 2*b)/((1 - b)*C);  % koeficijent integralnog dejstva; [izraz (46)]
freg = -log(Sopt)/(2*pi*T);             % propusni opseg brzinske petlje; [izraz (47)]
%--------------------------------------------------------------------------------------------------------%
%START MODEL C.mdl
open_system('c.mdl');
open_system('c/TRACE/trace');
%--------------------------------------------------------------------------------------------------------%

